@@ -15,9 +15,7 @@
 #include "highlighter.h"
 #include "ideutils.h"
 
-Theme Themes::currentTheme = Themes::minizinc;
-
-Highlighter::Highlighter(QFont& font, bool dm, QTextDocument *parent)
+Highlighter::Highlighter(QFont& font, const Theme& theme, bool dm, QTextDocument *parent)
     : QSyntaxHighlighter(parent), keywordColor(Qt::darkGreen), functionColor(Qt::blue), stringColor(Qt::darkRed), commentColor(Qt::red)
 
 {
@@ -64,7 +62,7 @@ Highlighter::Highlighter(QFont& font, bool dm, QTextDocument *parent)
     commentStartExp = QRegularExpression("/\\*");
     commentEndExp = QRegularExpression("\\*/");
 
-    setDarkMode(dm);
+    setTheme(theme, dm);
 
 }
 
@@ -154,7 +152,7 @@ void Highlighter::highlightBlock(const QString &text)
                     } else {
                         // /*
                         highlightingState.push_back(HS_COMMENT);
-                        curPosition = nxt+1;
+                        curPosition = nxt+2;
                     }
                 }
             }
@@ -183,7 +181,7 @@ void Highlighter::highlightBlock(const QString &text)
         case HS_COMMENT:
             {
                 int nxt = commentRegexp.match(text, curPosition).capturedStart();
-                int commentStartIdx = curPosition==0 ? 0 : curPosition-1;
+                int commentStartIdx = curPosition <= 1 ? 0 : curPosition - 2;
                 if (nxt==-1) {
                     // EOL -> stay in COMMENT state
                     setFormat(commentStartIdx, text.size()-commentStartIdx, commentFormat);
@@ -191,7 +189,7 @@ void Highlighter::highlightBlock(const QString &text)
                 } else {
                     // finish comment
                     setFormat(commentStartIdx, nxt-commentStartIdx+2, commentFormat);
-                    curPosition = nxt+1;
+                    curPosition = nxt+2;
                     highlightingState.pop_back();
                 }
             }
@@ -362,13 +360,12 @@ void Highlighter::copyHighlightedToClipboard(QTextCursor cursor)
     delete tempDocument;
 }
 
-void Highlighter::setDarkMode(bool enable)
+void Highlighter::setTheme(const Theme& theme, bool darkMode)
 {
-    darkMode = enable;
-    keywordColor = Themes::currentTheme.keywordColor.get(darkMode);
-    functionColor = Themes::currentTheme.functionColor.get(darkMode);
-    stringColor = Themes::currentTheme.stringColor.get(darkMode);
-    commentColor = Themes::currentTheme.commentColor.get(darkMode);
+    keywordColor = theme.keywordColor.get(darkMode);
+    functionColor = theme.functionColor.get(darkMode);
+    stringColor = theme.stringColor.get(darkMode);
+    commentColor = theme.commentColor.get(darkMode);
     commentFormat.setForeground(commentColor);
     rules[0].format.setForeground(functionColor);
     for (int i=1; i<rules.size(); i++) {
