@@ -20,6 +20,7 @@
 #include "moocsubmission.h"
 #include "exception.h"
 #include "configwindow.h"
+#include "history.h"
 
 class Project : public QObject {
     Q_OBJECT
@@ -211,6 +212,14 @@ public:
         return itemModel;
     }
 
+    History* history() const
+    {
+        if (mooc == nullptr) {
+            return nullptr;
+        }
+        return mooc->history;
+    }
+
 signals:
     ///
     /// \brief Emitted when a file gets renamed
