@@ -169,6 +169,7 @@ static int getRandomExID()
 void Conductor::onExecutionDone(Execution *e)
 {
     e->tree().setDone();
+    emit executionFinish(e);
 
     if (options_.save_search_path != "")
     {
@@ -240,6 +241,7 @@ void Conductor::handleStart(ReceiverThread *receiver, const std::string &ex_name
 
         /// needs a new execution
         auto ex = addNewExecution(ex_name_used, ex_id, restarts);
+        emit executionStart(ex);
 
         /// construct a name map
         if (ide_used)
@@ -321,6 +323,16 @@ Execution *Conductor::addNewExecution(const std::string &ex_name, int ex_id, boo
     return ex.get();
 }
 
+
+Execution* Conductor::getExecution(int exec_id)
+{
+    auto it = executions_.find(exec_id);
+    if (it == executions_.end()) {
+        return nullptr;
+    }
+    return &*it->second;
+}
+
 ExecutionWindow &Conductor::getExecutionWindow(Execution *e)
 {
     auto maybe_view = execution_windows_.find(e);
@@ -330,7 +342,8 @@ ExecutionWindow &Conductor::getExecutionWindow(Execution *e)
     {
         execution_windows_[e] = new ExecutionWindow(*e, this);
 
-        const auto ex_window = execution_windows_[e];
+        auto* ex_window = execution_windows_[e];
+        ex_window->setDarkMode(dark_mode_);
 
         connect(ex_window, &ExecutionWindow::needToSaveSearch, [this, e]() {
             saveSearch(e);
@@ -636,6 +649,14 @@ void Conductor::computeHeatMap(ExecID eid, std::vector<NodeID> ns)
     emit showNogood(url.c_str(), label.str().c_str(), false);
 }
 
+void Conductor::setDarkMode(bool d)
+{
+    dark_mode_ = d;
+    for (auto& it : execution_windows_) {
+        it.second->setDarkMode(d);
+    }
+}
+
 } // namespace cpprofiler
 
 namespace cpprofiler
