@@ -9,7 +9,7 @@ namespace utils
 MaybeCaller::MaybeCaller(int min_ms) : min_elapsed_(min_ms)
 {
     updateTimer.setSingleShot(true);
-    connect(&updateTimer, SIGNAL(timeout()), this, SLOT(callViaTimer()));
+    connect(&updateTimer, &QTimer::timeout, this, &MaybeCaller::callViaTimer);
     last_call_time = std::chrono::system_clock::now();
 }
 
@@ -36,4 +36,4 @@ void MaybeCaller::call(std::function<void(void)> fn)
 void MaybeCaller::callViaTimer() { delayed_fn(); }
 
 } // namespace utils
-} // namespace cpprofiler
\ No newline at end of file
+} // namespace cpprofiler
